# voicemode-channel

VoiceMode Channel - inbound voice calls to Claude Code via VoiceMode Connect.

This is a placeholder package to reserve the name. See the full project at:
https://github.com/mbailey/voicemode-channel
